@@ -1,3 +1,4 @@
+from dataclasses import dataclass
 import os
 import datetime
 import pytz
@@ -6,12 +7,52 @@ from getpass import getuser
 import random
 import firexkit
 import shutil
+import re
+from typing import Optional
+from collections import namedtuple
 
 from firexapp.submit.arguments import whitelist_arguments
 from firexkit.permissions import DEFAULT_CHMOD_MODE
 
 BASE_LOGGING_DIR_ENV_VAR_KEY = 'firex_base_logging_dir'
 
+FIREX_ID_DATE_FMT = "%y%m%d-%H%M%S"
+FIREX_ID_REGEX = re.compile(r'^FireX-(?P<user>.*?)-(?P<datetime_str>\d{6}-\d{6})-(?P<random_int>\d+)$')
+
+
+def firex_id_str(user: str, timestamp: datetime.datetime, random_int: int) -> str:
+    return f'FireX-{user}-{timestamp.strftime(FIREX_ID_DATE_FMT)}-{random_int}'
+
+
+@dataclass(frozen=True)
+class FireXIdParts:
+    user: str
+    timestamp: datetime.datetime
+    random_int: int
+
+    def firex_id(self):
+        return firex_id_str(self.user, self.timestamp, self.random_int)
+
+
+def get_firex_id_parts(maybe_firex_id: str) -> Optional[FireXIdParts]:
+    m = FIREX_ID_REGEX.match(maybe_firex_id)
+    if m:
+        parts = m.groupdict()
+        try:
+             tz_unaware_datetime = datetime.datetime.strptime(
+                parts['datetime_str'],
+                FIREX_ID_DATE_FMT)
+        except ValueError:
+            pass # invalidate date format.
+        else:
+            tz_aware_datetime = pytz.utc.localize(tz_unaware_datetime)
+            return FireXIdParts(parts['user'], tz_aware_datetime, int(parts['random_int']))
+    return None
+
+
+def is_firex_id(maybe_firex_id: str) -> bool:
+    return bool(get_firex_id_parts(maybe_firex_id))
+
 
 class Uid(object):
     debug_dirname = 'firex_internal'
@@ -24,7 +65,7 @@ class Uid(object):
             self.identifier = identifier
         else:
             random.seed()
-            self.identifier = f'FireX-{self.user}-{self.timestamp.strftime("%y%m%d-%H%M%S")}-{random.randint(1, 65536)}'
+            self.identifier = firex_id_str(self.user, self.timestamp, random.randint(1, 65536))
         self._base_logging_dir = None
         self._logs_dir = None
         self._debug_dir = None
@@ -106,5 +147,10 @@ class Uid(object):
         except KeyError:
             return None
 
+    @property
+    def run_data(self):
+        return {'firex_id': self.identifier,
+                'logs_path': self.logs_dir}
+
 
 whitelist_arguments("uid")
